スイッチサイエンスマガジン用プログラム。 Switch Science mbed TY51822r3を使って、Eddystoneを動かしています。

Dependencies:   BLE_API mbed nRF51822

Fork of mbed_EddystoneURL_Beacon_ssci by Mako SHIMURA

Revision:
1:0ad7573b5918
Parent:
0:094734b4e8bd
--- a/ConfigParamsPersistence.h	Mon Aug 17 04:41:01 2015 +0000
+++ b/ConfigParamsPersistence.h	Tue Aug 18 00:45:39 2015 +0000
@@ -17,10 +17,10 @@
 #ifndef __BLE_CONFIG_PARAMS_PERSISTENCE_H__
 #define __BLE_CONFIG_PARAMS_PERSISTENCE_H__
 
-#include "ble/services/URIBeaconConfigService.h"
+#include "ble/services/EddystoneURLConfigService.h"
 
 /**
  * Generic API to load the URIBeacon configuration parameters from persistent
  * storage. If persistent storage isn't available, the persistenceSignature
  * member of params may be left un-initialized to the MAGIC, and this will cause
  * a reset to default values.
@@ -33,10 +33,10 @@
  * @return true if params were loaded from persistent storage and have usefully
  *         initialized fields.
  */
-bool loadURIBeaconConfigParams(URIBeaconConfigService::Params_t *paramsP);
+bool loadEddystoneURLConfigParams(EddystoneURLConfigService::Params_t *paramsP);
 
 /**
  * Generic API to store the URIBeacon configuration parameters to persistent
  * storage. It typically initializes the persistenceSignature member of the
  * params to the MAGIC value to indicate persistence.
  *
@@ -48,6 +48,6 @@
  *                    The params to be saved; persistenceSignature member gets
  *                    updated if persistence is successful.
  */
-void saveURIBeaconConfigParams(const URIBeaconConfigService::Params_t *paramsP);
+void saveEddystoneURLConfigParams(const EddystoneURLConfigService::Params_t *paramsP);
 
 #endif /* #ifndef __BLE_CONFIG_PARAMS_PERSISTENCE_H__*/
@@ -17,10 +17,10 @@
 
 /**
- * Generic API to load the URIBeacon configuration parameters from persistent
+ * Generic API to load the Eddystone-URL configuration parameters from persistent
  * storage. If persistent storage isn't available, the persistenceSignature
  * member of params may be left un-initialized to the MAGIC, and this will cause
@@ -33,10 +33,10 @@
 
 /**
- * Generic API to store the URIBeacon configuration parameters to persistent
+ * Generic API to store the Eddystone-URL configuration parameters to persistent
  * storage. It typically initializes the persistenceSignature member of the
  * params to the MAGIC value to indicate persistence.